'use strict';

var react = require('@kubb/react');
var oas = require('@kubb/oas');
var utils = require('@kubb/core/utils');
var utils$1 = require('@kubb/plugin-oas/utils');
var jsxRuntime = require('@kubb/react/jsx-runtime');

// src/components/Mutation.tsx
function getParams({ paramsType, paramsCasing, pathParamsType, typeSchemas }) {
  if (paramsType === "object") {
    return react.FunctionParams.factory({
      data: {
        mode: "object",
        children: {
          ...utils$1.getPathParams(typeSchemas.pathParams, { typed: true, casing: paramsCasing }),
          data: typeSchemas.request?.name ? {
            type: typeSchemas.request?.name,
            optional: oas.isOptional(typeSchemas.request?.schema)
          } : void 0,
          params: typeSchemas.queryParams?.name ? {
            type: typeSchemas.queryParams?.name,
            optional: oas.isOptional(typeSchemas.queryParams?.schema)
          } : void 0,
          headers: typeSchemas.headerParams?.name ? {
            type: typeSchemas.headerParams?.name,
            optional: oas.isOptional(typeSchemas.headerParams?.schema)
          } : void 0
        }
      },
      config: {
        type: typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>",
        default: "{}"
      }
    });
  }
  return react.FunctionParams.factory({
    pathParams: typeSchemas.pathParams?.name ? {
      mode: pathParamsType === "object" ? "object" : "inlineSpread",
      children: utils$1.getPathParams(typeSchemas.pathParams, { typed: true, casing: paramsCasing }),
      optional: oas.isOptional(typeSchemas.pathParams?.schema)
    } : void 0,
    data: typeSchemas.request?.name ? {
      type: typeSchemas.request?.name,
      optional: oas.isOptional(typeSchemas.request?.schema)
    } : void 0,
    params: typeSchemas.queryParams?.name ? {
      type: typeSchemas.queryParams?.name,
      optional: oas.isOptional(typeSchemas.queryParams?.schema)
    } : void 0,
    headers: typeSchemas.headerParams?.name ? {
      type: typeSchemas.headerParams?.name,
      optional: oas.isOptional(typeSchemas.headerParams?.schema)
    } : void 0,
    config: {
      type: typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>",
      default: "{}"
    }
  });
}
function Client({
  name,
  isExportable = true,
  isIndexable = true,
  typeSchemas,
  baseURL,
  dataReturnType,
  parser,
  zodSchemas,
  paramsType,
  paramsCasing,
  pathParamsType,
  operation
}) {
  const path = new utils.URLPath(operation.path, { casing: paramsCasing });
  const contentType = operation.getContentType();
  const isFormData = contentType === "multipart/form-data";
  const headers = [
    contentType !== "application/json" ? `'Content-Type': '${contentType}'` : void 0,
    typeSchemas.headerParams?.name ? "...headers" : void 0
  ].filter(Boolean);
  const generics = [
    typeSchemas.response.name,
    typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error",
    typeSchemas.request?.name || "unknown"
  ].filter(Boolean);
  const params = getParams({ paramsType, paramsCasing, pathParamsType, typeSchemas });
  const clientParams = react.FunctionParams.factory({
    config: {
      mode: "object",
      children: {
        method: {
          value: JSON.stringify(operation.method.toUpperCase())
        },
        url: {
          value: path.template
        },
        baseURL: baseURL ? {
          value: JSON.stringify(baseURL)
        } : void 0,
        params: typeSchemas.queryParams?.name ? {} : void 0,
        data: typeSchemas.request?.name ? {
          value: isFormData ? "formData" : void 0
        } : void 0,
        headers: headers.length ? {
          value: headers.length ? `{ ${headers.join(", ")}, ...config.headers }` : void 0
        } : void 0,
        config: {
          mode: "inlineSpread"
        }
      }
    }
  });
  const formData = isFormData ? `
   const formData = new FormData()
   if(data) {
    Object.keys(data).forEach((key) => {
      const value = data[key as keyof typeof data];
      if (typeof key === "string" && (typeof value === "string" || value instanceof Blob)) {
        formData.append(key, value);
      }
    })
   }
  ` : "";
  return /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable, isIndexable, children: /* @__PURE__ */ jsxRuntime.jsxs(
    react.Function,
    {
      name,
      async: true,
      export: isExportable,
      params: params.toConstructor(),
      JSDoc: {
        comments: utils$1.getComments(operation)
      },
      children: [
        formData,
        `const res = await client<${generics.join(", ")}>(${clientParams.toCall()})`,
        /* @__PURE__ */ jsxRuntime.jsx("br", {}),
        dataReturnType === "full" && parser === "zod" && zodSchemas && `return {...res, data: ${zodSchemas.response.name}.parse(res.data)}`,
        dataReturnType === "data" && parser === "zod" && zodSchemas && `return ${zodSchemas.response.name}.parse(res.data)`,
        dataReturnType === "full" && parser === "client" && "return res",
        dataReturnType === "data" && parser === "client" && "return res.data"
      ]
    }
  ) });
}
Client.getParams = getParams;
function getParams2({}) {
  return react.FunctionParams.factory({});
}
var getTransformer = ({ operation, casing }) => {
  const path = new utils.URLPath(operation.path, { casing });
  return [JSON.stringify({ url: path.path })].filter(Boolean);
};
function MutationKey({ name, typeSchemas, paramsCasing, pathParamsType, operation, typeName, transformer = getTransformer }) {
  const params = getParams2({ pathParamsType, typeSchemas });
  const keys = transformer({ operation, schemas: typeSchemas, casing: paramsCasing });
  return /* @__PURE__ */ jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [
    /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable: true, isIndexable: true, children: /* @__PURE__ */ jsxRuntime.jsx(react.Function.Arrow, { name, export: true, params: params.toConstructor(), singleLine: true, children: `[${keys.join(", ")}] as const` }) }),
    /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name: typeName, isExportable: true, isIndexable: true, isTypeOnly: true, children: /* @__PURE__ */ jsxRuntime.jsx(react.Type, { name: typeName, export: true, children: `ReturnType<typeof ${name}>` }) })
  ] });
}
MutationKey.getParams = getParams2;
MutationKey.getTransformer = getTransformer;
function getParams3({ paramsCasing, dataReturnType, typeSchemas }) {
  const TData = dataReturnType === "data" ? typeSchemas.response.name : `ResponseConfig<${typeSchemas.response.name}>`;
  const mutationParams = react.FunctionParams.factory({
    ...utils$1.getPathParams(typeSchemas.pathParams, {
      typed: true,
      casing: paramsCasing,
      override(item) {
        return {
          ...item,
          type: `MaybeRef<${item.type}>`
        };
      }
    }),
    data: typeSchemas.request?.name ? {
      type: `MaybeRef<${typeSchemas.request?.name}>`,
      optional: oas.isOptional(typeSchemas.request?.schema)
    } : void 0,
    params: typeSchemas.queryParams?.name ? {
      type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
      optional: oas.isOptional(typeSchemas.queryParams?.schema)
    } : void 0,
    headers: typeSchemas.headerParams?.name ? {
      type: `MaybeRef<${typeSchemas.headerParams?.name}>`,
      optional: oas.isOptional(typeSchemas.headerParams?.schema)
    } : void 0
  });
  const TRequest = mutationParams.toConstructor({ valueAsType: true });
  return react.FunctionParams.factory({
    options: {
      type: `
{
  mutation?: MutationObserverOptions<${[TData, typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error", TRequest ? `{${TRequest}}` : void 0].filter(Boolean).join(", ")}>,
  client?: ${typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>"},
}
`,
      default: "{}"
    }
  });
}
function Mutation({
  name,
  clientName,
  paramsCasing,
  paramsType,
  pathParamsType,
  dataReturnType,
  typeSchemas,
  operation,
  mutationKeyName
}) {
  const mutationKeyParams = MutationKey.getParams({
    pathParamsType,
    typeSchemas
  });
  const params = getParams3({
    paramsCasing,
    pathParamsType,
    dataReturnType,
    typeSchemas
  });
  const clientParams = Client.getParams({
    paramsCasing,
    paramsType,
    typeSchemas,
    pathParamsType
  });
  const mutationParams = react.FunctionParams.factory({
    ...utils$1.getPathParams(typeSchemas.pathParams, { typed: true, casing: paramsCasing }),
    data: typeSchemas.request?.name ? {
      type: typeSchemas.request?.name,
      optional: oas.isOptional(typeSchemas.request?.schema)
    } : void 0,
    params: typeSchemas.queryParams?.name ? {
      type: typeSchemas.queryParams?.name,
      optional: oas.isOptional(typeSchemas.queryParams?.schema)
    } : void 0,
    headers: typeSchemas.headerParams?.name ? {
      type: typeSchemas.headerParams?.name,
      optional: oas.isOptional(typeSchemas.headerParams?.schema)
    } : void 0
  });
  const dataParams = react.FunctionParams.factory({
    data: {
      // No use of pathParams because useMutation can only take one argument in object form,
      // see https://tanstack.com/query/latest/docs/framework/react/reference/useMutation#usemutation
      mode: "object",
      children: Object.entries(mutationParams.params).reduce((acc, [key, value]) => {
        if (value) {
          acc[key] = {
            ...value,
            type: void 0
          };
        }
        return acc;
      }, {})
    }
  });
  const TRequest = mutationParams.toConstructor({ valueAsType: true });
  const TData = dataReturnType === "data" ? typeSchemas.response.name : `ResponseConfig<${typeSchemas.response.name}>`;
  const generics = [TData, typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error", TRequest ? `{${TRequest}}` : void 0].filter(Boolean).join(", ");
  return /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable: true, isIndexable: true, children: /* @__PURE__ */ jsxRuntime.jsx(
    react.Function,
    {
      name,
      export: true,
      params: params.toConstructor(),
      JSDoc: {
        comments: utils$1.getComments(operation)
      },
      children: `
        const { mutation: mutationOptions, client: config = {} } = options ?? {}
        const mutationKey = mutationOptions?.mutationKey ?? ${mutationKeyName}(${mutationKeyParams.toCall()})

        return useMutation<${generics}>({
          mutationFn: async(${dataParams.toConstructor()}) => {
            return ${clientName}(${clientParams.toCall()})
          },
          mutationKey,
          ...mutationOptions
        })
    `
    }
  ) });
}
function getParams4({ pathParamsType, paramsCasing, typeSchemas }) {
  return react.FunctionParams.factory({
    pathParams: {
      mode: pathParamsType === "object" ? "object" : "inlineSpread",
      children: utils$1.getPathParams(typeSchemas.pathParams, {
        typed: true,
        casing: paramsCasing,
        override(item) {
          return {
            ...item,
            type: `MaybeRef<${item.type}>`
          };
        }
      })
    },
    data: typeSchemas.request?.name ? {
      type: `MaybeRef<${typeSchemas.request?.name}>`,
      optional: oas.isOptional(typeSchemas.request?.schema)
    } : void 0,
    params: typeSchemas.queryParams?.name ? {
      type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
      optional: oas.isOptional(typeSchemas.queryParams?.schema)
    } : void 0
  });
}
var getTransformer2 = ({ operation, schemas, casing }) => {
  const path = new utils.URLPath(operation.path, { casing });
  const keys = [
    path.toObject({
      type: "path",
      stringify: true
    }),
    schemas.queryParams?.name ? "...(params ? [params] : [])" : void 0,
    schemas.request?.name ? "...(data ? [data] : [])" : void 0
  ].filter(Boolean);
  return keys;
};
function QueryKey({ name, typeSchemas, paramsCasing, pathParamsType, operation, typeName, transformer = getTransformer2 }) {
  const params = getParams4({ pathParamsType, typeSchemas, paramsCasing });
  const keys = transformer({
    operation,
    schemas: typeSchemas,
    casing: paramsCasing
  });
  return /* @__PURE__ */ jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [
    /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable: true, isIndexable: true, children: /* @__PURE__ */ jsxRuntime.jsx(react.Function.Arrow, { name, export: true, params: params.toConstructor(), singleLine: true, children: `[${keys.join(", ")}] as const` }) }),
    /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name: typeName, isExportable: true, isIndexable: true, isTypeOnly: true, children: /* @__PURE__ */ jsxRuntime.jsx(react.Type, { name: typeName, export: true, children: `ReturnType<typeof ${name}>` }) })
  ] });
}
QueryKey.getParams = getParams4;
QueryKey.getTransformer = getTransformer2;
function getParams5({ paramsType, paramsCasing, pathParamsType, typeSchemas }) {
  if (paramsType === "object") {
    return react.FunctionParams.factory({
      data: {
        mode: "object",
        children: {
          ...utils$1.getPathParams(typeSchemas.pathParams, {
            typed: true,
            casing: paramsCasing,
            override(item) {
              return {
                ...item,
                type: `MaybeRef<${item.type}>`
              };
            }
          }),
          data: typeSchemas.request?.name ? {
            type: `MaybeRef<${typeSchemas.request?.name}>`,
            optional: oas.isOptional(typeSchemas.request?.schema)
          } : void 0,
          params: typeSchemas.queryParams?.name ? {
            type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
            optional: oas.isOptional(typeSchemas.queryParams?.schema)
          } : void 0,
          headers: typeSchemas.headerParams?.name ? {
            type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
            optional: oas.isOptional(typeSchemas.headerParams?.schema)
          } : void 0
        }
      },
      config: {
        type: typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>",
        default: "{}"
      }
    });
  }
  return react.FunctionParams.factory({
    pathParams: {
      mode: pathParamsType === "object" ? "object" : "inlineSpread",
      optional: oas.isOptional(typeSchemas.pathParams?.schema),
      children: utils$1.getPathParams(typeSchemas.pathParams, {
        typed: true,
        casing: paramsCasing,
        override(item) {
          return {
            ...item,
            type: `MaybeRef<${item.type}>`
          };
        }
      })
    },
    data: typeSchemas.request?.name ? {
      type: `MaybeRef<${typeSchemas.request?.name}>`,
      optional: oas.isOptional(typeSchemas.request?.schema)
    } : void 0,
    params: typeSchemas.queryParams?.name ? {
      type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
      optional: oas.isOptional(typeSchemas.queryParams?.schema)
    } : void 0,
    headers: typeSchemas.headerParams?.name ? {
      type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
      optional: oas.isOptional(typeSchemas.headerParams?.schema)
    } : void 0,
    config: {
      type: typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>",
      default: "{}"
    }
  });
}
function QueryOptions({ name, clientName, typeSchemas, paramsCasing, paramsType, pathParamsType, queryKeyName }) {
  const params = getParams5({ paramsType, paramsCasing, pathParamsType, typeSchemas });
  const clientParams = Client.getParams({
    paramsType,
    paramsCasing,
    typeSchemas,
    pathParamsType
  });
  const queryKeyParams = QueryKey.getParams({
    pathParamsType,
    typeSchemas,
    paramsCasing
  });
  const enabled = Object.entries(queryKeyParams.flatParams).map(([key, item]) => item && !item.optional ? key : void 0).filter(Boolean).join("&& ");
  const enabledText = enabled ? `enabled: !!(${enabled}),` : "";
  return /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable: true, isIndexable: true, children: /* @__PURE__ */ jsxRuntime.jsx(react.Function, { name, export: true, params: params.toConstructor(), children: `
      const queryKey = ${queryKeyName}(${queryKeyParams.toCall()})
      return queryOptions({
      ${enabledText}
       queryKey,
       queryFn: async ({ signal }) => {
          config.signal = signal
          return ${clientName}(${clientParams.toCall({
    transformName(name2) {
      return `unref(${name2})`;
    }
  })})
       },
      })
` }) });
}
QueryOptions.getParams = getParams5;
function getParams6({ paramsCasing, paramsType, pathParamsType, dataReturnType, typeSchemas }) {
  const TData = dataReturnType === "data" ? typeSchemas.response.name : `ResponseConfig<${typeSchemas.response.name}>`;
  if (paramsType === "object") {
    return react.FunctionParams.factory({
      data: {
        mode: "object",
        children: {
          ...utils$1.getPathParams(typeSchemas.pathParams, {
            typed: true,
            casing: paramsCasing,
            override(item) {
              return {
                ...item,
                type: `MaybeRef<${item.type}>`
              };
            }
          }),
          data: typeSchemas.request?.name ? {
            type: `MaybeRef<${typeSchemas.request?.name}>`,
            optional: oas.isOptional(typeSchemas.request?.schema)
          } : void 0,
          params: typeSchemas.queryParams?.name ? {
            type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
            optional: oas.isOptional(typeSchemas.queryParams?.schema)
          } : void 0,
          headers: typeSchemas.headerParams?.name ? {
            type: `MaybeRef<${typeSchemas.headerParams?.name}>`,
            optional: oas.isOptional(typeSchemas.headerParams?.schema)
          } : void 0
        }
      },
      options: {
        type: `
{
  query?: Partial<QueryObserverOptions<${[TData, typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error", "TData", "TQueryData", "TQueryKey"].join(", ")}>>,
  client?: ${typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>"}
}
`,
        default: "{}"
      }
    });
  }
  return react.FunctionParams.factory({
    pathParams: {
      mode: pathParamsType === "object" ? "object" : "inlineSpread",
      optional: oas.isOptional(typeSchemas.pathParams?.schema),
      children: utils$1.getPathParams(typeSchemas.pathParams, {
        typed: true,
        casing: paramsCasing,
        override(item) {
          return {
            ...item,
            type: `MaybeRef<${item.type}>`
          };
        }
      })
    },
    data: typeSchemas.request?.name ? {
      type: `MaybeRef<${typeSchemas.request?.name}>`,
      optional: oas.isOptional(typeSchemas.request?.schema)
    } : void 0,
    params: typeSchemas.queryParams?.name ? {
      type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
      optional: oas.isOptional(typeSchemas.queryParams?.schema)
    } : void 0,
    headers: typeSchemas.headerParams?.name ? {
      type: `MaybeRef<${typeSchemas.headerParams?.name}>`,
      optional: oas.isOptional(typeSchemas.headerParams?.schema)
    } : void 0,
    options: {
      type: `
{
  query?: Partial<QueryObserverOptions<${[TData, typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error", "TData", "TQueryData", "TQueryKey"].join(", ")}>>,
  client?: ${typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>"}
}
`,
      default: "{}"
    }
  });
}
function Query({
  name,
  queryKeyTypeName,
  queryOptionsName,
  queryKeyName,
  paramsType,
  paramsCasing,
  pathParamsType,
  dataReturnType,
  typeSchemas,
  operation
}) {
  const TData = dataReturnType === "data" ? typeSchemas.response.name : `ResponseConfig<${typeSchemas.response.name}>`;
  const returnType = `UseQueryReturnType<${["TData", typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error"].join(", ")}> & { queryKey: TQueryKey }`;
  const generics = [`TData = ${TData}`, `TQueryData = ${TData}`, `TQueryKey extends QueryKey = ${queryKeyTypeName}`];
  const queryKeyParams = QueryKey.getParams({
    pathParamsType,
    typeSchemas,
    paramsCasing
  });
  const queryOptionsParams = QueryOptions.getParams({
    paramsType,
    pathParamsType,
    typeSchemas,
    paramsCasing
  });
  const params = getParams6({
    paramsCasing,
    paramsType,
    pathParamsType,
    dataReturnType,
    typeSchemas
  });
  const queryOptions = `${queryOptionsName}(${queryOptionsParams.toCall()}) as unknown as QueryObserverOptions`;
  return /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable: true, isIndexable: true, children: /* @__PURE__ */ jsxRuntime.jsx(
    react.Function,
    {
      name,
      export: true,
      generics: generics.join(", "),
      params: params.toConstructor(),
      JSDoc: {
        comments: utils$1.getComments(operation)
      },
      children: `
       const { query: queryOptions, client: config = {} } = options ?? {}
       const queryKey = queryOptions?.queryKey ?? ${queryKeyName}(${queryKeyParams.toCall()})

       const query = useQuery({
        ...${queryOptions},
        queryKey: queryKey as QueryKey,
        ...queryOptions as unknown as Omit<QueryObserverOptions, "queryKey">
       }) as ${returnType}

       query.queryKey = queryKey as TQueryKey

       return query
       `
    }
  ) });
}
Query.getParams = getParams6;
function getParams7({ paramsType, paramsCasing, pathParamsType, typeSchemas }) {
  if (paramsType === "object") {
    return react.FunctionParams.factory({
      data: {
        mode: "object",
        children: {
          ...utils$1.getPathParams(typeSchemas.pathParams, {
            typed: true,
            casing: paramsCasing,
            override(item) {
              return {
                ...item,
                type: `MaybeRef<${item.type}>`
              };
            }
          }),
          data: typeSchemas.request?.name ? {
            type: `MaybeRef<${typeSchemas.request?.name}>`,
            optional: oas.isOptional(typeSchemas.request?.schema)
          } : void 0,
          params: typeSchemas.queryParams?.name ? {
            type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
            optional: oas.isOptional(typeSchemas.queryParams?.schema)
          } : void 0,
          headers: typeSchemas.headerParams?.name ? {
            type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
            optional: oas.isOptional(typeSchemas.headerParams?.schema)
          } : void 0
        }
      },
      config: {
        type: typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>",
        default: "{}"
      }
    });
  }
  return react.FunctionParams.factory({
    pathParams: {
      mode: pathParamsType === "object" ? "object" : "inlineSpread",
      optional: oas.isOptional(typeSchemas.pathParams?.schema),
      children: utils$1.getPathParams(typeSchemas.pathParams, {
        typed: true,
        casing: paramsCasing,
        override(item) {
          return {
            ...item,
            type: `MaybeRef<${item.type}>`
          };
        }
      })
    },
    data: typeSchemas.request?.name ? {
      type: `MaybeRef<${typeSchemas.request?.name}>`,
      optional: oas.isOptional(typeSchemas.request?.schema)
    } : void 0,
    params: typeSchemas.queryParams?.name ? {
      type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
      optional: oas.isOptional(typeSchemas.queryParams?.schema)
    } : void 0,
    headers: typeSchemas.headerParams?.name ? {
      type: `MaybeRef<${typeSchemas.headerParams?.name}>`,
      optional: oas.isOptional(typeSchemas.headerParams?.schema)
    } : void 0,
    config: {
      type: typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>",
      default: "{}"
    }
  });
}
function InfiniteQueryOptions({
  name,
  clientName,
  initialPageParam,
  cursorParam,
  typeSchemas,
  paramsType,
  paramsCasing,
  dataReturnType,
  pathParamsType,
  queryParam,
  queryKeyName
}) {
  const params = getParams7({ paramsType, paramsCasing, pathParamsType, typeSchemas });
  const clientParams = Client.getParams({
    paramsType,
    paramsCasing,
    typeSchemas,
    pathParamsType
  });
  const queryKeyParams = QueryKey.getParams({
    paramsCasing,
    pathParamsType,
    typeSchemas
  });
  const queryOptions = [
    `initialPageParam: ${typeof initialPageParam === "string" ? JSON.stringify(initialPageParam) : initialPageParam}`,
    cursorParam ? `getNextPageParam: (lastPage) => lastPage['${cursorParam}']` : void 0,
    cursorParam ? `getPreviousPageParam: (firstPage) => firstPage['${cursorParam}']` : void 0,
    !cursorParam && dataReturnType === "full" ? "getNextPageParam: (lastPage, _allPages, lastPageParam) => Array.isArray(lastPage.data) && lastPage.data.length === 0 ? undefined : lastPageParam + 1" : void 0,
    !cursorParam && dataReturnType === "data" ? "getNextPageParam: (lastPage, _allPages, lastPageParam) => Array.isArray(lastPage) && lastPage.length === 0 ? undefined : lastPageParam + 1" : void 0,
    !cursorParam ? "getPreviousPageParam: (_firstPage, _allPages, firstPageParam) => firstPageParam <= 1 ? undefined : firstPageParam - 1" : void 0
  ].filter(Boolean);
  const infiniteOverrideParams = queryParam && typeSchemas.queryParams?.name ? `
          if(params) {
           params['${queryParam}'] = pageParam as unknown as ${typeSchemas.queryParams?.name}['${queryParam}']
          }` : "";
  const enabled = Object.entries(queryKeyParams.flatParams).map(([key, item]) => item && !item.optional ? key : void 0).filter(Boolean).join("&& ");
  const enabledText = enabled ? `enabled: !!(${enabled}),` : "";
  return /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable: true, isIndexable: true, children: /* @__PURE__ */ jsxRuntime.jsx(react.Function, { name, export: true, params: params.toConstructor(), children: `
      const queryKey = ${queryKeyName}(${queryKeyParams.toCall()})
      return infiniteQueryOptions({
       ${enabledText}
       queryKey,
       queryFn: async ({ signal, pageParam }) => {
          config.signal = signal
          ${infiniteOverrideParams}
          return ${clientName}(${clientParams.toCall()})
       },
       ${queryOptions.join(",\n")}
      })
` }) });
}
InfiniteQueryOptions.getParams = getParams7;
function getParams8({ paramsType, paramsCasing, pathParamsType, dataReturnType, typeSchemas }) {
  const TData = dataReturnType === "data" ? typeSchemas.response.name : `ResponseConfig<${typeSchemas.response.name}>`;
  if (paramsType === "object") {
    return react.FunctionParams.factory({
      data: {
        mode: "object",
        children: {
          ...utils$1.getPathParams(typeSchemas.pathParams, {
            typed: true,
            casing: paramsCasing,
            override(item) {
              return {
                ...item,
                type: `MaybeRef<${item.type}>`
              };
            }
          }),
          data: typeSchemas.request?.name ? {
            type: `MaybeRef<${typeSchemas.request?.name}>`,
            optional: oas.isOptional(typeSchemas.request?.schema)
          } : void 0,
          params: typeSchemas.queryParams?.name ? {
            type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
            optional: oas.isOptional(typeSchemas.queryParams?.schema)
          } : void 0,
          headers: typeSchemas.headerParams?.name ? {
            type: `MaybeRef<${typeSchemas.headerParams?.name}>`,
            optional: oas.isOptional(typeSchemas.headerParams?.schema)
          } : void 0
        }
      },
      options: {
        type: `
{
  query?: Partial<InfiniteQueryObserverOptions<${[TData, typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error", "TData", "TQueryData", "TQueryKey"].join(", ")}>>,
  client?: ${typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>"}
}
`,
        default: "{}"
      }
    });
  }
  return react.FunctionParams.factory({
    pathParams: {
      mode: pathParamsType === "object" ? "object" : "inlineSpread",
      optional: oas.isOptional(typeSchemas.pathParams?.schema),
      children: utils$1.getPathParams(typeSchemas.pathParams, {
        typed: true,
        casing: paramsCasing,
        override(item) {
          return {
            ...item,
            type: `MaybeRef<${item.type}>`
          };
        }
      })
    },
    data: typeSchemas.request?.name ? {
      type: `MaybeRef<${typeSchemas.request?.name}>`,
      optional: oas.isOptional(typeSchemas.request?.schema)
    } : void 0,
    params: typeSchemas.queryParams?.name ? {
      type: `MaybeRef<${typeSchemas.queryParams?.name}>`,
      optional: oas.isOptional(typeSchemas.queryParams?.schema)
    } : void 0,
    headers: typeSchemas.headerParams?.name ? {
      type: `MaybeRef<${typeSchemas.headerParams?.name}>`,
      optional: oas.isOptional(typeSchemas.headerParams?.schema)
    } : void 0,
    options: {
      type: `
{
  query?: Partial<InfiniteQueryObserverOptions<${[TData, typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error", "TData", "TQueryData", "TQueryKey"].join(", ")}>>,
  client?: ${typeSchemas.request?.name ? `Partial<RequestConfig<${typeSchemas.request?.name}>>` : "Partial<RequestConfig>"}
}
`,
      default: "{}"
    }
  });
}
function InfiniteQuery({
  name,
  queryKeyTypeName,
  queryOptionsName,
  queryKeyName,
  paramsType,
  pathParamsType,
  paramsCasing,
  dataReturnType,
  typeSchemas,
  operation
}) {
  const TData = dataReturnType === "data" ? typeSchemas.response.name : `ResponseConfig<${typeSchemas.response.name}>`;
  const returnType = `UseInfiniteQueryReturnType<${["TData", typeSchemas.errors?.map((item) => item.name).join(" | ") || "Error"].join(", ")}> & { queryKey: TQueryKey }`;
  const generics = [`TData = InfiniteData<${TData}>`, `TQueryData = ${TData}`, `TQueryKey extends QueryKey = ${queryKeyTypeName}`];
  const queryKeyParams = QueryKey.getParams({
    pathParamsType,
    typeSchemas,
    paramsCasing
  });
  const queryOptionsParams = QueryOptions.getParams({
    paramsType,
    pathParamsType,
    typeSchemas,
    paramsCasing
  });
  const params = getParams8({
    paramsCasing,
    paramsType,
    pathParamsType,
    dataReturnType,
    typeSchemas
  });
  const queryOptions = `${queryOptionsName}(${queryOptionsParams.toCall()}) as unknown as InfiniteQueryObserverOptions`;
  return /* @__PURE__ */ jsxRuntime.jsx(react.File.Source, { name, isExportable: true, isIndexable: true, children: /* @__PURE__ */ jsxRuntime.jsx(
    react.Function,
    {
      name,
      export: true,
      generics: generics.join(", "),
      params: params.toConstructor(),
      JSDoc: {
        comments: utils$1.getComments(operation)
      },
      children: `
       const { query: queryOptions, client: config = {} } = options ?? {}
       const queryKey = queryOptions?.queryKey ?? ${queryKeyName}(${queryKeyParams.toCall()})

       const query = useInfiniteQuery({
        ...${queryOptions},
        queryKey: queryKey as QueryKey,
        ...queryOptions as unknown as Omit<InfiniteQueryObserverOptions, "queryKey">
       }) as ${returnType}

       query.queryKey = queryKey as TQueryKey

       return query
       `
    }
  ) });
}
InfiniteQuery.getParams = getParams8;

exports.Client = Client;
exports.InfiniteQuery = InfiniteQuery;
exports.InfiniteQueryOptions = InfiniteQueryOptions;
exports.Mutation = Mutation;
exports.MutationKey = MutationKey;
exports.Query = Query;
exports.QueryKey = QueryKey;
exports.QueryOptions = QueryOptions;
//# sourceMappingURL=chunk-X3AYO2AG.cjs.map
//# sourceMappingURL=chunk-X3AYO2AG.cjs.map